{ config, pkgs, lib, inputs, ... }:

{
  nixpkgs.config.allowUnfree = true;

  home = {
    username = "unrooted";
    homeDirectory = "/home/unrooted";

    # Add locations to PATH
    sessionPath = [ "~/.local/bin" ];

    # Add environment variables
    sessionVariables = {
      EDITOR = "emacs";
    };

    file = {
      xresources = {
        source = ./Xresources;
        target = "~/.Xresources";
      };
    };

    stateVersion = "21.05";
  };

  imports = [
    ./zsh.nix
    ./xmonad/default.nix
    ./emacs.nix
    ./home_apps.nix
  ];

  programs = {
    home-manager.enable = true;
    git = {
      enable = true;
      userName = "Unrooted";
      userEmail = "konrad.root.klawikowski@gmail.com";
    };
  }; 

  packages = with pkgs; [
    (st.overrideAttrs (oa: {
      version = "modified"
      src = fetchFromGithub {
        owner = "LukeSmithxyz";
        repo = "st";
        rev = "67ef1c4d4ec3d3a423a078eb746fa2fac4a267e9";
        sha256 = "sha256-eiNkW0U0BYg1r075KEqWbiQKSPWoZIS3Epl3SYCnTYQ=";
        fetchSubmodules = true;
      };
      postPatch = ''
        substituteInPlace Makefile \
          --replace "git submodule init" "# git submodule init" \
          --replace "git submodule update" "# git submodule update"
      '';
      buildInputs = oa.buildInputs ++ [ harfbuzz ];
    }))
  ];

  services = {
    udiskie = {
      enable = true;
      automount = true;
      notify = true;
      tray = "never";
    };
    caffeine = {
      enable = true;
    };
    screen-locker = {
      enable = true;
      lockCmd = "${pkgs.slock}/bin/slock";
      inactiveInterval = 10;
    };
  };

}
